### Name: Drink
### Title: Water Temperature Effect on Cow Drinking
### Aliases: Drink
### Keywords: datasets

### ** Examples

# Average measurement per cow
data( Drink )

Drink2 <- Drink[Drink$period < 3,]
Drink4 <- Drink[!is.na(match(Drink$cow,Drink$cow[Drink$period == 4])),]

Drink$cow <- factor( Drink$cow )
Drink$month <- ordered( Drink$month )
Drink$period <- ordered( Drink$period )
Drink.fit <- aov( milk ~ cow + period * water, Drink )

Drink2$cow <- factor( Drink2$cow )
Drink2$month <- ordered( Drink2$month )
Drink2$period <- ordered( Drink2$period )
Drink2.fit <- aov( milk ~ cow + period * water, Drink2 )

Drink4$cow <- factor( Drink4$cow )
Drink4$month <- ordered( Drink4$month )
Drink4$period <- ordered( Drink4$period )
Drink4.fit <- aov( milk ~ cow + period * water, Drink4 )

# I:27.1 Drink cross-over interaction plots
lsd.plot( Drink2.fit, factors = c("period","water"),
  xpos = 1.25, xlab = "(a) cows in first two periods",
  ylab = "7-day milk yield (lb)",
  main = "Figure 27.1",
  more = TRUE, split = c(1,1,2,1) )
lsd.plot( Drink4.fit, factors = c("period","water"),
  xpos = 1.75, xlab = "(b) cows in all four periods", ylab = "",
  main = "Drink",
  split = c(2,1,2,1) )

# better approach: mixed model fit using lme()
library(lme4)
Drink2.lme <- lmer(milk ~ period * water + (1|cow),
  data = Drink2 )
summary(Drink2.lme)
anova(Drink2.lme)
VarCorr( Drink2.lme)

int.plot( Drink2.lme, factors = c("period","water"),
   xpos = 1.25, xlab = "(a) cows in first two periods",
   ylab = "7-day milk yield (lb)", bar = "ellipse" )

Drink4.lme <- lmer(milk ~ period * water + (1|cow),
  data = Drink4 )
Drink4.lme
anova(Drink4.lme)
VarCorr( Drink4.lme)

int.plot( Drink4.lme, factors = c("period","water"),
   xpos = 1.75, xlab = "(b) cows in all four periods",
   ylab = "", bar = "ellipse" )
int.plot( Drink4.lme, factors = c("water","period"),
   xpos = 1.75, xlab = "(c) cold vs hot",
   ylab = "", bar = "ellipse" )



