### Name: Hardy
### Title: Cold Hardiness Adaptation
### Aliases: Hardy
### Keywords: datasets

### ** Examples

data( Hardy )

Hardy$potato <- factor(Hardy$potato)
Hardy$regime <- factor(Hardy$regime)
Hardy$temp <- factor(Hardy$temp)

# full model: you may want to consider various reduced models */
Hardy.fit <- aov(leak ~ potato * regime * temp, Hardy)
# Type I sums of squares
summary( Hardy.fit )
# Type III sums of squares
drop1( Hardy.fit, formula( Hardy.fit ), test = "F" )

# Least Squares means
Hardy.lsm <- lsmean(Hardy.fit)
# default plots for lm object
plot(Hardy.fit)

# diagnostic plot of resid vs predict with 0 line and +/- 1 SD
Hardy$code = factor( Hardy$code )
xyplot( resid(Hardy.fit) ~ jitter(predict(Hardy.fit)),
  groups = Hardy$code, pch = levels( Hardy$code ), cex = 1.5,
  panel = function(x,y,sd=std.dev(Hardy.fit),...){
    panel.xyplot(x,y,...)
    panel.abline(0,0,lty=2)
    panel.abline(sd,0,lty=3)
    panel.abline(-sd,0,lty=3)
  } )

# interaction plot with LSD bars (but play with this!)
lsd.plot(Hardy.fit,Hardy,c("potato","regime"),
  more = TRUE, split = c(1,1,2,1) )
# the following give a slightly different plot -- why?
attach(Hardy)
lsd.plot(potato,leak,regime, split = c(2,1,2,1))
detach()

# side-by-side interaction plots for the subsets of t=1,2
lsd.plot(Hardy.fit,Hardy,c("potato","regime"),
  Hardy.lsm[Hardy.lsm$temp==1,],
  more = TRUE, split = c(1,1,2,1) )
lsd.plot(Hardy.fit,Hardy,c("potato","regime"),
  Hardy.lsm[Hardy.lsm$temp==2,],
  split = c(2,1,2,1) )



