### Name: Tomato
### Title: Tomato data to find genes for growth
### Aliases: Tomato
### Keywords: datasets

### ** Examples

data( Tomato )

# make sure entry, tg430 and yr are all factors
Tomato$entry <- factor( Tomato$entry )
Tomato$tg430 <- ordered( Tomato$tg430, c("A","H","B") )
Tomato$yr <- ordered( Tomato$yr )
# reduce to complete data
Tomato1 <- Tomato[ !( is.na( Tomato$tg430 )
   | is.na( Tomato$mfwlog ))
   & Tomato$yr == 1, ]

# Figure 4.1: Histograms
histogram( ~ mfwlog | tg430, Tomato1, nint = 30, layout = c(1,3),
  main = "Figure B:4.1. Tomato Histograms by Group" )

# Figure 4.2: Box-Plots
bwplot( mfwlog ~ tg430, Tomato1,
  xlab = "Tomato Allele Type", ylab= "Log Flower Time",
  main = "Figure B:4.2. Tomato Box-Plots by Group" )

# Figure 5.1: Confidence Intervals

# fit one-factor anova
Tomato.aov <- aov( mfwlog ~ tg430, Tomato1 )
Tomato.aov
summary( Tomato.aov )
# least squares means ( uses library( pda ) )
lsmean( Tomato.aov )

# 95
ci.plot( Tomato.aov, level = 0.05,
   crit=qt( 1 - 0.05 / 2, df.resid( Tomato.aov )) / sqrt(2),
   xlab=paste("(a) ",100 * ( 1 - 0.05 ),
      "% CI / sqrt(2)", sep = "" ),
   ylab = "log flower time",
   main = "Figure 5.1(a) Confidence Intervals",
  split = c(1,1,1,1) )

# notched box-plots to compare with CIs (NA in bwplot currently)
attach( Tomato1 )
boxplot( split( mfwlog, tg430 ), notch = TRUE,
   xlab = "(b) notched box-plots",
   ylab = "log flower time",
   main = "Figure 5.1(b) Tomato Notched Box-Plots" )
detach()



