### Name: Wasp
### Title: Wasp Shape of Queens and Workers
### Aliases: Wasp
### Keywords: datasets

### ** Examples

data( Wasp )

## Multivariate discriminant analysis
library(MASS)
Wasp.lda <- lda( Wasp[,-1], Wasp$caste )
Wasp.lda
Wasp$DA <- predict( Wasp.lda, Wasp[,-1] )$x

## Univariate t statistics
tmp <- Wasp$caste == "Q"
Wasp.t <- apply( Wasp[,-1], 2, function( x ) {
   ( mean( x[tmp] ) - mean( x[!tmp] ) ) /
   sqrt( ( var( x[tmp] ) + var( x[!tmp] ) ) / sum( tmp ) ) } )
rm( tmp )
Wasp.t <- sort( Wasp.t )
Wasp.tmpy <- cor( Wasp[,2:14], Wasp$DA )[ names( Wasp.t[-1] ), 1 ]

## Figure F:18.2 Wasp scatter plots

pairs( Wasp[ , c("HW","TW","G1Wa","DA") ], panel =
   function( x, y, ... ) {
     text( x, y, as.character( Wasp$caste ) ) },
   labels = c("head","thorax","gonadium",
     "discriminant\nanalysis" ) )
title( "Figure F:18.2 Wasp scatter plots" )

## Figure F:18.3 Wasp discriminant analysis

plot( c(1,-1) * Wasp.t["DA"], c(1,-1), type = "n",
   xlab ="t statistics", ylab = "correlation with DA" )
text( c(1,-1) * Wasp.t["DA"], c(1,-1), "DA" )
lines( Wasp.t[-1], Wasp.tmpy )
points( Wasp.t[-1], Wasp.tmpy )
text( Wasp.t[-1] + 5 * sign( Wasp.t[-1] ),
  uncollide(Wasp.tmpy,.05), names( Wasp.t[-1] ) )
abline(h=0,v=0,lty=2)
mtext("queen larger",1,2,adj=1)
mtext("worker larger",1,2,adj=0)
title( "Figure F:18.3 Wasp discriminant analysis" )

# Figure F:18.5 Wasp analysis of covariance

Wasp.cov <- aov( HW ~ G1Wa * caste, Wasp )
anova( Wasp.cov )
Wasp.par <- aov( HW ~ G1Wa + caste, Wasp )
anova( Wasp.par )

print(xyplot(HW ~ G1Wa, Wasp, group = caste, type = "p",
  pch = levels(Wasp$caste), col = 1 + seq(along = levels(Wasp$caste)),
  panel = function(x,y,...) {
    panel.superpose(x,y,...)
    lc = levels(Wasp$caste)
    for(i in seq( along = lc )) {
      ii = lc[i] == Wasp$caste
      panel.lines(Wasp$G1Wa[ii], predict(Wasp.cov)[ii],
        lty = 3, col = i)
      panel.lines(Wasp$G1Wa[ii], predict(Wasp.par)[ii],
        lty = 1, col = i)
    }
  },
  xlab ="(a) gonadium width (G1Wa)",
  ylab = "head width (HW)",
  main = "Figure F:18.5 Wasp" ),
  more = TRUE, split = c(1,1,2,1) )

## residual analysis after removing TW
Wasp.resid <- Wasp[,c("caste","HW","G1Wa","TW")]
Wasp.resid$Hres <- resid( aov( HW ~ TW, Wasp.resid ) )
Wasp.resid$Gres <- resid( aov( G1Wa ~ TW, Wasp.resid ) )
Wasp.covr <- aov( Hres ~ TW + G1Wa + caste, Wasp.resid )
anova( Wasp.covr )
Wasp.covwr <- aov( Hres ~ G1Wa + caste, Wasp.resid )
anova( Wasp.covwr )
Wasp.resid$TW <- rep( mean( Wasp.resid$TW ), nrow( Wasp.resid ) )

print(xyplot(Hres ~ G1Wa, Wasp.resid, group = caste, type = "p",
  pch = levels(Wasp.resid$caste), col = 1 + seq(along = levels(Wasp.resid$caste)),
  panel = function(x,y,...) {
    panel.superpose(x,y,...)
    lc = levels(Wasp.resid$caste)
    for( i in seq(along = lc)) {
      ii = lc[i] == Wasp.resid$caste
      panel.lines(Wasp.resid$G1Wa[ii], predict(Wasp.covr, Wasp.resid)[ii],
        lty = 1, col = i )
      panel.lines(Wasp$G1Wa[ii], predict(Wasp.covwr)[ii],
        lty = 3, col = i )
    }
  },
  xlab ="(b) gonadium width (G1Wa)",
  ylab = "HW residuals on TW",
  main = "Analysis of Covariance" ),
  split = c(2,1,2,1) )



